use crate::MainDialogue;
use cryptography::passwords::check_master_pass;
use sea_orm::DatabaseConnection;
use teloxide::{adaptors::Throttle, prelude::*};

const INVALID_MASTER_PASS_MESSAGE: &str = "Master password is invalid. It must be at least 8 characters long. \
It also has to contain at least one lowercase, one uppercase, one number and one punctuation character";

/// Checks that the account with that name exists
#[inline]
async fn check_new_master_pass(
    bot: &Throttle<Bot>,
    msg: &Message,
    password: &str,
) -> crate::Result<Option<Message>> {
    let is_valid = check_master_pass(password);
    if !is_valid {
        let msg = bot
            .send_message(msg.chat.id, INVALID_MASTER_PASS_MESSAGE)
            .await?;
        return Ok(Some(msg));
    }
    Ok(None)
}

/// Handles GetNewMasterPass state
pub async fn get_new_master_pass(
    bot: Throttle<Bot>,
    msg: Message,
    db: DatabaseConnection,
    dialogue: MainDialogue,
    next: super::PackagedHandler<String>,
) -> crate::Result<()> {
    super::generic::generic(
        bot,
        msg,
        db,
        dialogue,
        |bot, msg, _, password| Box::pin(check_new_master_pass(bot, msg, password)),
        "Couldn't get the text of the message. Send the master password again",
        next,
    )
    .await
}
